==> hk2-extras-2.4.0-b17-sources.jar: org/glassfish/hk2/extras/operation/internal/OperationDescriptor.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2015 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.hk2.extras.operation.internal;

import java.lang.annotation.Annotation;

import org.glassfish.hk2.api.ServiceHandle;
import org.glassfish.hk2.extras.operation.OperationHandle;
import org.glassfish.hk2.utilities.AbstractActiveDescriptor;

/**
 * @author jwells
 *
 */
public class OperationDescriptor extends AbstractActiveDescriptor<OperationHandle> {
    private final SingleOperationManager parent;
    
    public OperationDescriptor(Annotation scope, SingleOperationManager parent) {
        this.parent = parent;
        
        setImplementation(OperationHandleImpl.class.getName());
        addContractType(OperationHandle.class);
        
        setScopeAsAnnotation(scope);
    }

    /* (non-Javadoc)
     * @see org.glassfish.hk2.api.ActiveDescriptor#getImplementationClass()
     */
    @Override
    public Class<?> getImplementationClass() {
        return OperationHandleImpl.class;
    }

    /* (non-Javadoc)
     * @see org.glassfish.hk2.api.ActiveDescriptor#create(org.glassfish.hk2.api.ServiceHandle)
     */
    @Override
    public OperationHandle create(ServiceHandle<?> root) {
        OperationHandleImpl retVal = parent.getCurrentOperationOnThisThread();
        if (retVal == null) {
            throw new IllegalStateException("There is no active operation in scope " +
                getScopeAnnotation().getName() + " on thread " + Thread.currentThread().getId());
        }
        
        return retVal;
    }

}

==> hk2-extras-2.5.0-b32-sources.jar: org/glassfish/hk2/extras/operation/internal/OperationDescriptor.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2015-2016 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.hk2.extras.operation.internal;

import java.lang.annotation.Annotation;
import java.lang.reflect.Type;

import org.glassfish.hk2.api.ServiceHandle;
import org.glassfish.hk2.extras.operation.OperationHandle;
import org.glassfish.hk2.utilities.AbstractActiveDescriptor;
import org.glassfish.hk2.utilities.reflection.ParameterizedTypeImpl;

/**
 * @author jwells
 *
 */
public class OperationDescriptor<T extends Annotation> extends AbstractActiveDescriptor<OperationHandle<T>> {
    private final SingleOperationManager<T> parent;
    
    public OperationDescriptor(T scope, SingleOperationManager<T> parent) {
        this.parent = parent;
        
        setImplementation(OperationHandleImpl.class.getName());
        addContractType(new ParameterizedTypeImpl(OperationHandle.class, scope.annotationType()));
        
        setScopeAsAnnotation(scope);
    }

    /* (non-Javadoc)
     * @see org.glassfish.hk2.api.ActiveDescriptor#getImplementationClass()
     */
    @Override
    public Class<?> getImplementationClass() {
        return OperationHandleImpl.class;
    }

    @Override
    public Type getImplementationType() {
        return OperationHandleImpl.class;
    }

    @Override
    public void setImplementationType(Type t) {
        throw new AssertionError("Cannot set type of OperationHandle");
    }

    /* (non-Javadoc)
     * @see org.glassfish.hk2.api.ActiveDescriptor#create(org.glassfish.hk2.api.ServiceHandle)
     */
    @Override
    public OperationHandle<T> create(ServiceHandle<?> root) {
        OperationHandleImpl<T> retVal = parent.getCurrentOperationOnThisThread();
        if (retVal == null) {
            throw new IllegalStateException("There is no active operation in scope " +
                getScopeAnnotation().getName() + " on thread " + Thread.currentThread().getId());
        }
        
        return retVal;
    }

}
